clear all
set more off, perm

//load parameters
insheet using param.csv, delimiter(",") clear
su v1
global etaH `r(mean)'
su v2
global etaL `r(mean)'
su v3
global tetaI `r(mean)'
su v4
global tetaE `r(mean)'
su v5
global L `r(mean)'


// initialize outcome values and moments
local outcome1 = 0
local outcome2 = 0
local outcome3 = 0
local outcome4 = 0
local outcome5 = 0
local outcome6 = 0
local outcome7 = 0
local outcome8 = 0
local outcome9 = 0
local outcome10 = 0
local outcome11 = 0
local outcome12 = 0
	
local M1 = 0
local M2 = 0
local M3 = 0
local M4 = 0
local M5 = 0
local M6 = 0
	
local T = 500
forvalues i = 1/`T' {
disp `i'
qui {
	insheet using data`i'.csv, delimiter(",") clear
	
	rename v1 state
	rename v2 year			
	rename v3 mu
	rename v4 top1
	//rename v5 top1noerr
	rename v6 xI
	rename v7 xE
	rename v8 errtet
	//rename v9 top1fixerr
	rename v10 paterr
	
	rename v11 ratio_entrant_inc
	su ratio_entrant_inc
	local M2 = `M2' + `r(mean)'
	rename v12 avg_markup
	su avg_markup
	local M4 = `M4'+`r(mean)'
	rename v13 emp_share
	su emp_share
	local M5 = `M5'+`r(mean)'
	rename v14 growth
	su growth
	local M6 = `M6'+`r(mean)'
	
	
	xtset state year, yearly

	gen logtop=log(top1)
	gen logpat=log(mu)
	gen logpaterr=log(paterr)

	//for info only
	summarize logpat
	
	// patents with measurement errors
	summarize logpaterr
	local outcome1 = `outcome1'+`r(sd)'
	
	// top 1% income share
	summarize top1
	local outcome2 = `outcome2'+`r(mean)'
	local outcome3 = `outcome3'+`r(sd)'

	// Total innovation rate mu
	summarize mu
	local outcome4 = `outcome4'+`r(mean)'

	// Part of the errors on patents which is not state specific
	reg logpaterr i.state
	predict varlogpat, residuals
	summarize varlogpat
	local outcome5 = `outcome5'+`r(sd)'

	// The error on predicted patent
	reg logpaterr errtet i.state i.year
	predict logpaterrfirst

	summarize logpaterrfirst
	local outcome6 = `outcome6'+`r(sd)'

	// The error on predicted patent which is not state specific
	reg logpaterrfirst i.state
	predict varlogpatfirst, residuals

	summarize varlogpatfirst
	local outcome7 = `outcome7'+`r(sd)'

	//**** The regressions:
	
	// OLS with noise on patents
	xtreg logtop logpaterr i.year, fe //0.0578
	local tmp=_b[logpaterr]
	local outcome8 = `outcome8' + `tmp'

	
	// IV
	xtivreg logtop i.year (logpaterr = errtet), fe //0.167
	local tmp=_b[logpaterr]
	local outcome9 = `outcome9' + `tmp'
	
	//* OLS without noise on patents
	xtreg logtop logpat i.year, fe //0.0832
	local tmp=_b[logpat]
	local outcome10 = `outcome10' + `tmp'
	
	//*** Fixed effect predicted
	xi:ivreg logtop i.year i.state (logpaterr = errtet)
	local count = 0
	forvalues j = 2/51 {
		local count = `count' + _b[_Istate_`j' ]/50
	}
	local sd = 0
	forvalues j = 2/51 {
		local sd = `sd' + (_b[_Istate_`j' ]-`count')^2
	}
	local sd = sqrt(`sd'/50)
	local outcome11= `outcome11'+`sd' // s.d. of state fixed effects
	
	local count = 0
	forvalues j = 2/28 {
		local count = `count' + _b[_Iyear_`j' ]/27
	}
	local sd = 0
	forvalues j = 2/28 {
		local sd = `sd' + (_b[_Iyear_`j' ]-`count')^2
	}
	local sd = sqrt(`sd'/27)
	local outcome12= `outcome12'+`sd' // s.d. of year fixed effects
	
}
}


local outcome1 = `outcome1' / `T'
local outcome2 = `outcome2' / `T'
local outcome3 = `outcome3' / `T'
local outcome4 = `outcome4' / `T'
local outcome5 = `outcome5' / `T'
local outcome6 = `outcome6' / `T'
local outcome7 = `outcome7' / `T'
local outcome8 = `outcome8' / `T'
local outcome9 = `outcome9' / `T'
local outcome10 = `outcome10' / `T'
local outcome11 = `outcome11' / `T'
local outcome12 = `outcome12' / `T'
local M2 = `M2'/`T'
local M4 = `M4'/`T'
local M5 = `M5'/`T'
local M6 = `M6'/`T'
local M3 = `outcome9'
local M1 = `outcome2'

disp "M1"
disp `M1'
disp "M2"
disp `M2'
disp "M3"
disp `M3'
disp "M4"
disp `M4'
disp "M5"
disp `M5'
disp "M6"
disp `M6'


disp "SD of logpaterr (expected: 1.348)"
disp `outcome1'
* We found 1.107

disp "Mean of top1 (expected: 0.13)"
disp `outcome2'
* We found 0.13

disp "SD of top1 (expected: 0.0463)"
disp `outcome3'
* We found 0.056

disp "Mean of mu (expected: 0.202)"
disp `outcome4'
* This is not a target as it is not observed in the data.
* The model once calibrated predicts a value of 0.202, we found 0.196 here

disp "SD of patents controling for state f.e. (expected: 0.744)"
disp `outcome5'
* We found 0.889.

disp "SD of predicted patent (expected: 1.057)"
disp `outcome6'
* We found 0.959.

disp "SD of predicted patent controling for state f.e. (expected: 0.702)"
disp `outcome7'
* We found 0.697.

disp "Coeff  regression OLS (expected 0.049)"
disp `outcome8'
* We found 0.051

disp "Coeff regression IV (expected 0.185)"
disp `outcome9'
* We found 0.184

disp "Coeff regression OLS no measurement error"
disp `outcome10'
* We found 0.070

disp "sd of state FE (expected 0.173)"
disp `outcome11'
* We found 0.163

disp "sd of year FE (expected 0.325)"
disp `outcome12'
* We found 0.319

