// Appendix Replication file

use ../data/main_db, clear 
global graph = "../graphs"
set scheme s1mono, perm
program drop _all		
run ../programs/drawtable.do

sort id year

//Table C1: Top 0.1 and Top 0.01 income share incumbents and entrants
preserve
	qui {
		
		gen indexE = .
		gen indexI = .
		gen innovE = log(asg_entrant_cit5_corr_3y /pop)
		replace indexE = asg_entrant_cit5_corr_3y == 0
		replace innovE = 0 if asg_entrant_cit5_corr_3y == 0
		gen innovI = log(asg_incumbent_cit5_corr_3y /pop)
		replace indexI = asg_incumbent_cit5_corr_3y == 0
		replace innovI = 0 if asg_incumbent_cit5_corr_3y == 0

			xi:xtivreg2 ltop01 L2.innovE L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m1, title("Top 0.1\%")
			
			xi:xtivreg2 ltop01 L2.innovI L2.indexI lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m2, title("Top 0.1\%")	
					
			xi:xtivreg2 ltop01 L2.innovI L2.innovE L2.indexI L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m3, title("Top 0.1\%")			


			xi:xtivreg2 ltop001 L2.innovE L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m4, title("Top 0.01\%")
			

			xi:xtivreg2 ltop001 L2.innovI L2.indexI lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m5, title("Top 0.01\%")	
					
			xi:xtivreg2 ltop001 L2.innovI L2.innovE L2.indexI L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m6, title("Top 0.01\%")	
		
	}

	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations"))  drop(_* oL* *index*) label  order(L2.innovE L2.innovI) ///
	rename(lgdppc "Gdppc" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") varlabel(L2.innovE "Innovation by Entrants" L2.innovI "Innovation by Incumbents") varwidth(30)
	
restore


// Table C2 - Distribution of patents located by inventors and assignees
preserve
	keep if year == 2000
	collapse (sum) patent_asg patent, by(iso) fast
	egen den = sum(patent)
	replace patent = 100* patent / den
	drop den
	egen den = sum(patent_asg)
	replace patent_asg = 100*patent_asg/den
	drop den
	format patent patent_asg %12.1f
	order iso patent patent_asg
	drawtable patent patent_asg, by(iso) s(sum) 
restore

// Table C3: Top 1% income share and innovation allocation by assignee
preserve
	qui {
		recode patent_asg Cit5_corr_asg Generality_asg Claims_asg Top1_asg Top5_asg (missing=0)
		foreach var of varlist patent_asg Cit5_corr_asg  Generality_asg Claims_asg Top1_asg Top5_asg {
			replace `var' = . if year < 1976
		}
		
		gen innov = log(patent_asg/pop)
		replace innov = 0 if patent_asg == 0
		gen index = 1 if patent_asg == 0
			xi:xtivreg2 ltop1 L2.innov  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust bw(2) fe
			estimate store m1, title("Patents")
		
		replace innov = log(Cit5_corr_asg/pop)
		replace index = Cit5_corr_asg == 0
		replace innov = 0 if Cit5_corr_asg == 0	
			xi:xtivreg2 ltop1  L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m2, title("Citations")
		
		replace innov = log(Claims_asg/pop)
		replace index = Claims_asg == 0
		replace innov = 0 if Claims_asg == 0		
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust bw(2) fe
			estimate store m3, title("Claims")
		
		replace innov = log(Generality_asg/pop)
		replace index = Generality_asg == 0
		replace innov = 0 if Generality_asg == 0		
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth  finance gvt unemp  tax_gain tax_rate_wage   i.year if year <= 2011, robust bw(2) fe
			estimate store m4, title("Generality")
		
		replace innov = log(Top5_asg/pop)
		replace index = Top5_asg == 0
		replace innov = 0 if Top5_asg == 0
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if year <= 2008, robust bw(2) fe
			estimate store m5, title("Top 5")
		
		replace innov = log(Top1_asg/pop)
		replace index = Top1_asg == 0
		replace innov = 0 if Top1_asg == 0
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe
			estimate store m6, title("Top 1")	
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* L*index) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore

// Table C4 - Descriptive statistics by state in two distinctive years
preserve
	keep if year == 1980 | year == 2005 
	gen innov = Cit5_corr / pop
	keep innov year iso top1_adj
	replace innov = innov*1000000	
	reshape wide top1_adj innov, i(iso) j(year)
	format top1_adj* %12.2f
	format innov* %12.0f
	drawtable top1_adj1980 innov1980, by(iso) s(mean)
	drawtable top1_adj2005 innov2005, by(iso) s(mean)
restore
	
//Table C5: top 1% income share with clustered standard errors
preserve
	qui {
		sort id year
		gen index = .	
		gen innov = log(patent/pop)
		replace index = patent == 0
		
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust cluster(id) fe
			estimate store m1, title("Patents")
			
		replace innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust cluster(id) fe
			estimate store m2, title("Citations")
			
		replace innov = log(claims/pop)
		replace index = claims == 0
		replace innov = 0 if claims == 0	
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust cluster(id) fe
			estimate store m3, title("Claims")
			
		replace innov = log(generality/pop)
		replace index = generality == 0
		replace innov = 0 if generality == 0		
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp  tax_gain tax_rate_wage   i.year if year <= 2011, robust cluster(id) fe
			estimate store m4, title("Generality")
			
		replace innov = log(Top5/pop)
		replace index = Top5 == 0
		replace innov = 0 if Top5 == 0
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if year <= 2008, robust cluster(id) fe
			estimate store m5, title("Top 5")
			
		replace innov = log(Top1/pop)
		replace index = Top1 == 0
		replace innov = 0 if Top1 == 0
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust cluster(id) fe
			estimate store m6, title("Top 1")	
			
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* *index*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore


//Table C6 - Top 1% income share and innovation (OLS buildup)

preserve
	qui {
		gen innov = log(Cit5_corr/pop)
		gen index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
		
		xi:xtivreg2 ltop1  L2.innov L2.index  i.year  if year <= 2008 & tax_gain!=., robust bw(2) fe 
		estimate store m1		
		
		xi:xtivreg2 ltop1  L2.innov L2.index  lgdppc   popgrowth  i.year  if year <= 2008 & tax_gain!=., robust bw(2) fe 
		estimate store m2		
		
		xi:xtivreg2 ltop1  L2.innov L2.index  lgdppc    popgrowth finance gvt   i.year  if year <= 2008 & tax_gain!=., robust bw(2) fe 
		estimate store m3		
		
		xi:xtivreg2 ltop1  L2.innov L2.index   lgdppc   popgrowth finance gvt unemp   i.year  if year <= 2008 & tax_gain!=., robust bw(2) fe 
		estimate store m4	
		
		xi:xtivreg2 ltop1  L2.innov L2.index   lgdppc   popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2008 & tax_gain!=., robust bw(2) fe 
		estimate store m5
	
	}
	estout m1 m2 m3 m4 m5 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore

// Table C7 top 1% income share and number of entrepreneurs
// Data have been directly sent to us by Jorge Guzman and are consistent with the paper
// "The State of American Entrepreneurship: New Estimates of the Quantity and Quality of Entrepreneurship for 34 US States, 1988-2014"
// Jorge Guzman and Scott Stern

//Table C8: Alternative definition of entrants
preserve
	qui {
		gen indexE = .
		gen indexI = .
		gen innovE = log(asg_entrant_patent_5y/pop)
		replace indexE = asg_entrant_patent_5y == 0
		replace innovE = 0 if asg_entrant_patent_5y == 0
			xi:xtivreg2 ltop1 L2.innovE L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2011 & year>= 1982, robust bw(2) fe
			estimate store m1, title("Patents")
		
		gen innovI = log(asg_incumbent_patent_5y/pop)
		replace indexI = asg_incumbent_patent_5y == 0
		replace innovI = 0 if asg_incumbent_patent_5y == 0
			xi:xtivreg2 ltop1 L2.innovI L2.indexI lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2011 & year>= 1982, robust bw(2) fe
			estimate store m2, title("Patents")	
				
			xi:xtivreg2 ltop1 L2.innovI L2.innovE L2.indexI L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2011 & year>= 1982, robust bw(2) fe
			estimate store m3, title("Patents")	

		replace innovE = log(asg_entrant_cit5_corr_5y/pop)
		replace indexE = asg_entrant_cit5_corr_5y == 0
		replace innovE = 0 if asg_entrant_cit5_corr_5y == 0
			xi:xtivreg2 ltop1 L2.innovE L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m4, title("Cit5")
		
		replace innovI = log(asg_incumbent_cit5_corr_5y/pop)
		replace indexI = asg_incumbent_cit5_corr_5y == 0
		replace innovI = 0 if asg_incumbent_cit5_corr_5y == 0
			xi:xtivreg2 ltop1 L2.innovI L2.indexI lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m5, title("Cit5")	
				
			xi:xtivreg2 ltop1 L2.innovI L2.innovE L2.indexI L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m6, title("Cit5")			
		
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations"))  drop(_* L2.index*) label  order(L2.innovE L2.innovI) ///
	rename(lgdppc "Gdppc" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 	
restore

//Table C9: Descriptive statistics on the Senate appropriation committee composition
preserve
	keep if inrange(year, 1970, 2008)
	gen Senate1 = (SenateMember == 1)
	gen Senate2 = (SenateMember == 2)
	drawtable Senate1 Senate2, by(iso) s(sum)
restore

//Table C10: Other measures of inequality in IV
preserve
	qui {
		drop if iso == "DC"
		gen innov = log(Cit5_corr/pop)
		gen index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
		
			xi:xtivreg2 ltop1 (L2.innov=L5.Senate) L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe 
			estimate store m1, title(Top 1\%)
			local m1 = e(widstat)
			estadd scalar Fstat = `m1'	
			
			xi:xtivreg2 ltop10 (L2.innov=L5.Senate) L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe 
			estimate store m2, title(Top 10\%)
			local m2 = e(widstat)
			estadd scalar Fstat = `m2'	
			
			xi:xtivreg2 ltop9 (L2.innov=L5.Senate) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe 
			estimate store m3, title(Avgtop)
			local m3 = e(widstat)
			estadd scalar Fstat = `m3'	
			
			xi:xtivreg2 lgini (L2.innov=L5.Senate) L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe 
			estimate store m4, title(Gini)
			local m4 = e(widstat)
			estadd scalar Fstat = `m4'	
			
			xi:xtivreg2 lgini99 (L2.innov=L5.Senate) L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe 
			estimate store m5, title(Gini99)
			local m5 = e(widstat)
			estadd scalar Fstat = `m5'	
			
			xi:xtivreg2 latkin (L2.innov=L5.Senate) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008, robust bw(2) fe 
			estimate store m6, title(Atkin)
			local m6 = e(widstat)
			estadd scalar Fstat = `m6'	
			
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL" L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military")  varwidth(35)
restore


//Table C11: Top1% income share and innovation at different lags, IV results
preserve
	qui {
		drop if iso == "DC"
		gen instru = Senate
		gen innov = log(Cit5_corr/pop)
		gen index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
		xi:xtivreg2 ltop1 (L2.innov =  L5.instru ) L2.index  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008 & L9.instru != . & L6.innov != ., robust bw(2) fe 
		estimate store m1
		local m1 = e(widstat)	
		estadd scalar Fstat = `m1'	

		xi:xtivreg2 ltop1 (L3.innov =  L6.instru ) L3.index  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008  & L9.instru != . & L6.innov != ., robust bw(2) fe 
		estimate store m2
		local m2 = e(widstat)
		estadd scalar Fstat = `m2'	

		xi:xtivreg2 ltop1 (L4.innov =  L7.instru ) L4.index  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008  & L9.instru != . & L6.innov != ., robust bw(2) fe 
		estimate store m3
		local m3 = e(widstat)
		estadd scalar Fstat = `m3'	

		xi:xtivreg2 ltop1 (L5.innov =  L8.instru ) L5.index  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008  & L9.instru != . & L6.innov != ., robust bw(2) fe 
		estimate store m4
		local m4 = e(widstat)	
		estadd scalar Fstat = `m4'	

		xi:xtivreg2 ltop1 (L6.innov =  L9.instru ) L6.index  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008  & L9.instru != . & L6.innov != ., robust bw(2) fe 
		estimate store m5
		local m5 = e(widstat)			
		estadd scalar Fstat = `m5'	
	}
	estout m1 m2 m3 m4 m5, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation$_{t-2}$" L3.innov "Innovation$_{t-3}$" L4.innov "Innovation$_{t-4}$" L5.innov "Innovation$_{t-5}$" L6.innov "Innovation$_{t-6}$" lgdppc "Gdppc" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL" L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military") ///
	order("Innovation$_{t-2}$"  "Innovation$_{t-3}$" "Innovation$_{t-4}$" "Innovation$_{t-5}$" "Innovation$_{t-6}$") varwidth(35)
restore

//Table C12: Robustness 1: regression of innovation on top 1% income share using two instruments
preserve
	qui {		
		gen instru = Senate
		gen instru2 = log(instru_spill) 
		gen control = log(control_spillover)
		gen control2 = log(control_spill_indus)
		drop if iso == "DC"
		
		gen innov = log(patent/pop)
		gen index = patent == 0
		replace innov = 0 if patent == 0	
			xi:xtivreg2 ltop1 (L2.innov = L5.instru L3.instru2) L2.index  L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011 & year >=1982, robust bw(2) fe 
			estimate store m1
			local m1 = e(widstat)
			local O1 = e(jp)
			estadd scalar Fstat `m1'
			estadd scalar Jstat `O1'

		replace innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			xi:xtivreg2 ltop1 (L2.innov =  L5.instru L3.instru2) L2.index  L3.control L3.control2  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m2
			local m2 = e(widstat)	
			local O2 = e(jp)
			estadd scalar Fstat `m2'
			estadd scalar Jstat `O2'
			
		replace innov = log(claims/pop)
		replace index = claims == 0
		replace innov = 0 if claims == 0		
			xi:xtivreg2 ltop1 (L2.innov = L5.instru L3.instru2) L2.index  L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011 & year >=1982, robust bw(2) fe 
			estimate store m3
			local m3 = e(widstat)	
			local O3 = e(jp)
			estadd scalar Fstat `m3'
			estadd scalar Jstat `O3'	
		
		replace innov = log(generality/pop)
		replace index = generality == 0
		replace innov = 0 if generality == 0		
			xi:xtivreg2 ltop1 (L2.innov = L5.instru L3.instru2) L2.index   L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011 & year >=1982, robust bw(2) fe 
			estimate store m4
			local m4 = e(widstat)		
			local O4 = e(jp)
			estadd scalar Fstat `m4'
			estadd scalar Jstat `O4'
		
		replace innov = log(Top5/pop)
		replace index = Top5 == 0
		replace innov = 0 if Top5 == 0
			xi:xtivreg2 ltop1 (L2.innov = L5.instru L3.instru2) L2.index   L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m5	
			local m5 = e(widstat)		
			local O5 = e(jp)
			estadd scalar Fstat `m5'
			estadd scalar Jstat `O5'
		
		replace innov = log(Top1/pop)
		replace index = Top1 == 0
		replace innov = 0 if Top1 == 0
			xi:xtivreg2 ltop1 (L2.innov = L5.instru L3.instru2) L2.index   L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m6	
			local m6 = e(widstat)		
			local O6 = e(jp)
			estadd scalar Fstat `m6'
			estadd scalar Jstat `O6'		
	}
	estout m1 m2 m3 m4 m5 m6 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat Jstat N, fmt(%9.3f %9.1f %9.3f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Sargan-Hansen J-stat (p-value)" "Observations")) drop(_* oL* *control*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL" L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military") varwidth(40)
restore


//Table C13: Regression of innovation on top 1% income share using only the spillover instrument
preserve
	qui {		
		gen instru = log(instru_spill) 
		gen control = log(control_spillover)
		gen control2 = log(control_spill_indus)
		
		gen innov = log(patent/pop)
		gen index = patent == 0
		replace innov = 0 if patent == 0	
			xi:xtivreg2 ltop1 (L2.innov =  L3.instru) L2.index  L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year if year <= 2011 & year >=1982, robust bw(2) fe 
			estimate store m1
			local m1 = e(widstat)
			estadd scalar Fstat `m1'
			
		replace innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			xi:xtivreg2 ltop1 (L2.innov =  L3.instru) L2.index  L3.control L3.control2  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m2
			local m2 = e(widstat)	
			estadd scalar Fstat `m2'
			
		replace innov = log(claims/pop)
		replace index = claims == 0
		replace innov = 0 if claims == 0		
			xi:xtivreg2 ltop1 (L2.innov =  L3.instru) L2.index  L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year if year <= 2011 & year >=1982, robust bw(2) fe 
			estimate store m3
			local m3 = e(widstat)	
			estadd scalar Fstat `m3'
		
		replace innov = log(generality/pop)
		replace index = generality == 0
		replace innov = 0 if generality == 0		
			xi:xtivreg2 ltop1 (L2.innov =  L3.instru) L2.index   L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if year <= 2011 & year >=1982, robust bw(2) fe 
			estimate store m4
			local m4 = e(widstat)		
			estadd scalar Fstat `m4'
		
		replace innov = log(Top5/pop)
		replace index = Top5 == 0
		replace innov = 0 if Top5 == 0
			xi:xtivreg2 ltop1 (L2.innov =  L3.instru) L2.index   L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m5	
			local m5 = e(widstat)		
			estadd scalar Fstat `m5'
		
		replace innov = log(Top1/pop)
		replace index = Top1 == 0
		replace innov = 0 if Top1 == 0
			xi:xtivreg2 ltop1 (L2.innov =  L3.instru) L2.index   L3.control L3.control2 lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m6	
			local m6 = e(widstat)		
			estadd scalar Fstat `m6'
	}
	estout m1 m2 m3 m4 m5 m6 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* oL* *control*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") varwidth(40)
restore

//Table C14 uses CZ level data and is computed at the end of this dofile

//Table C15: The effectiveness of appropriability mechanisms for innovation
preserve
	qui {
	gen innov = log(Cit5_corr/pop)
	gen index = Cit5_corr == 0
	replace innov = 0 if Cit5_corr == 0	
	
	bys year: egen md = median(score_app_wgt_gdp)
	gen group = score_app_wgt_gdp >= md
	drop if score_app_wgt_gdp == .
	
	xi:xtivreg2 ltop1 L2.innov  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  i.year  if year <= 2008 & group == 1, robust bw(2) fe
	estimate store m1, title("Above wgt")	
	
	xi:xtivreg2 ltop1 L2.innov  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  i.year  if year <= 2008 & group == 0, robust bw(2) fe
	estimate store m2, title("below wgt")	
	
	gen interact = group * innov
	xi:xtivreg2 ltop1 L2.innov L2.interact L2.group  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  i.year  if year <= 2008, robust bw(2) fe
	estimate store m3, title("interact wgt")	
	}
	estout m1 m2 m3, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment"  tax_gain  "TaxK" tax_rate_wage "TaxL") 
restore



//Table C16: Robustness 2: financial sector and natural resources (OLS)
preserve
	qui {
	
	gen innov = log(Cit5_corr/pop)
	gen index = Cit5_corr == 0
	replace innov = 0 if Cit5_corr == 0	
	
	gen log_remun_finance = log(remun_finance)
	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage log_remun_finance i.year  if year <= 2008, robust bw(2) fe
		estimate store m1, title("Remun Finance")
	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & !inlist(iso, "NY", "CT", "DE", "MA"), robust bw(2) fe
		estimate store m2, title("No NY CT DE MA")
	
	replace innov = log((Cit5_corr-Cit5_corr_finance)/pop)
	replace index = Cit5_corr-Cit5_corr_finance == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_finance == 0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008, robust bw(2) fe
		estimate store m3, title("No finance patents")	
	
	replace innov = log(Cit5_corr/pop)
	replace index = Cit5_corr == 0
	replace innov = 0 if Cit5_corr == 0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage EFD i.year  if year <= 2008, robust bw(2) fe
		estimate store m4, title("Financial Dependence")		
	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage mining i.year  if year <= 2008, robust bw(2) fe
		estimate store m5, title("Control mining")	
	
	replace innov = log((Cit5_corr-Cit5_corr_extraction)/pop)
	replace index = Cit5_corr-Cit5_corr_extraction == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_extraction == 0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage i.year  if year <= 2008, robust bw(2) fe
		estimate store m6, title("No mining patents")	
	}
	label var EFD "EFD"
	label var log_remun_finance "RemunFinance"
	label var mining "Mining+Oil"
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) p(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations"))  drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc"  popgrowth "Popgrowth"  finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore


//Table C17: Robustness 2: financial sector and natural resources (IV)
preserve
	qui {
	
	gen innov = log(Cit5_corr/pop)
	gen index = Cit5_corr == 0
	replace innov = 0 if Cit5_corr == 0	
	gen log_remun_finance = log(remun_finance)
	gen instru = Senate
	drop if iso == "DC"
	
		xi:xtivreg2 ltop1 (L2.innov=L5.instru) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp log_remun_finance i.year  if year <= 2008, robust bw(2) fe
		estimate store m1, title("Remun Finance")
		local m1 = e(widstat)		
		estadd scalar Fstat `m1'
	
		xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008 & !inlist(iso, "NY", "CT", "DE", "MA"), robust bw(2) fe
		estimate store m2, title("No NY CT DE MA")
		local m2 = e(widstat)		
		estadd scalar Fstat `m2'
	
	replace innov = log((Cit5_corr-Cit5_corr_finance)/pop)
	replace index = Cit5_corr-Cit5_corr_finance == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_finance == 0	
		xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe
		estimate store m3, title("No finance patents")	
		local m3 = e(widstat)		
		estadd scalar Fstat `m3'
		
	replace innov = log(Cit5_corr/pop)
	replace index = Cit5_corr == 0
	replace innov = 0 if Cit5_corr == 0	
		xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index lgdppc popgrowth  finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp EFD i.year  if year <= 2008, robust bw(2) fe
		estimate store m4, title("Financial Dependence")		
		local m4 = e(widstat)		
		estadd scalar Fstat `m4'
	
		xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp mining i.year  if year <= 2008, robust bw(2) fe
		estimate store m5, title("Control mining")	
		local m5 = e(widstat)		
		estadd scalar Fstat `m5'
	
	replace innov = log((Cit5_corr-Cit5_corr_extraction)/pop)
	replace index = Cit5_corr-Cit5_corr_extraction == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_extraction == 0	
		xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp  i.year  if year <= 2008, robust bw(2) fe
		estimate store m6, title("No mining patents")	
		local m6 = e(widstat)
		estadd scalar Fstat `m6'
	}
	label var EFD "EFD"
	label var log_remun_finance "RemunFinance"
	label var mining "Mining+Oil"	
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL" L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military")  varwidth(35)
restore

//Table C18: Robustness 3: controlling for industry composition
preserve
	qui {
	
	gen innov = log((Cit5_corr-Cit5_corr_naics334)/pop)
	gen index = Cit5_corr-Cit5_corr_naics334 == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_naics334==0
		xi:xtivreg2 ltop1 L2.innov  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  i.year  if year <= 2008, robust bw(2) fe
		estimate store m1, title("Naics 334")
	
	replace innov = log((Cit5_corr-Cit5_corr_naics335)/pop)
	replace index = Cit5_corr-Cit5_corr_naics335 == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_naics335==0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage i.year  if year <= 2008, robust bw(2) fe
		estimate store m2, title("Naics 335")
	
	replace innov = log((Cit5_corr-Cit5_corr_naics3254)/pop)
	replace index = Cit5_corr-Cit5_corr_naics3254 == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_naics3254==0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  i.year  if year <= 2008, robust bw(2) fe
		estimate store m3, title("Naics 3254")	
	
	replace innov = log(Cit5_corr/pop)
	replace index = Cit5_corr == 0
	replace innov = 0 if Cit5_corr==0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  share325 share334 share335 i.year  if year <= 2008, robust bw(2) fe
		estimate store m4, title("Control")	
	
	replace innov = log((Cit5_corr-Cit5_corr_naics335-Cit5_corr_naics333-Cit5_corr_naics336)/pop)
	replace index = Cit5_corr-Cit5_corr_naics335-Cit5_corr_naics333-Cit5_corr_naics336 == 0
	replace innov = 0 if Cit5_corr-Cit5_corr_naics335-Cit5_corr_naics333-Cit5_corr_naics336==0	
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  i.year  if year <= 2008, robust bw(2) fe
		estimate store m5, title("Export")		
	}
	estout m1 m2 m3 m4 m5, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" finance "Finance" popgrowth "Popgrowth" gvt "Government" unemp "Unemployment"  tax_gain  "TaxK" tax_rate_wage "TaxL") ///
	varlabel(share325 "Computer and Electronic" share334 "Chemistry" share335 "Electrical Component") varwidth(30)
restore

//Table C19: Top 1% income share and innovation for single state inventors (OLS)
preserve
	qui {
	gen innov = log(patent_nomovers /pop)
	gen index = patent_nomovers == 0
	replace innov = 0 if patent_nomovers == 0
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust bw(2) fe
		estimate store m1, title("Patents")
	
	replace innov = log(Cit5_corr_nomovers /pop)
	replace index = Cit5_corr_nomovers == 0
	replace innov = 0 if Cit5_corr_nomovers == 0	
		xi:xtivreg2 ltop1  L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
		estimate store m2, title("Citations")
	
	replace innov = log(Claims_nomovers /pop)
	replace index = Claims_nomovers == 0
	replace innov = 0 if Claims_nomovers == 0		
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust bw(2) fe
		estimate store m3, title("Claims")
	
	replace innov = log(Generality_nomovers /pop)
	replace index = Generality_nomovers == 0
	replace innov = 0 if Generality_nomovers == 0		
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp  tax_gain tax_rate_wage   i.year if year <= 2011, robust bw(2) fe
		estimate store m4, title("Generality")
	
	replace innov = log(Top5_nomovers /pop)
	replace index = Top5_nomovers == 0
	replace innov = 0 if Top5_nomovers == 0
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if year <= 2008, robust bw(2) fe
		estimate store m5, title("Top 5")
	
	replace innov = log(Top1_nomovers /pop)
	replace index = Top1_nomovers == 0
	replace innov = 0 if Top1_nomovers == 0
		xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe
		estimate store m6, title("Top 1")	
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore


//Table C20: Top 1% income share and innovation for single state inventors (IV)
preserve
	qui {
		drop if iso == "DC"
		gen instru = Senate
		gen innov = log(patent_nomovers/pop)
		gen index = patent_nomovers == 0
		replace innov = 0 if patent_nomovers == 0	
		
			xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2011, robust bw(2) fe
			estimate store m1
			local m1 = e(widstat)
			estadd scalar Fstat `m1'
			
		replace innov = log(Cit5_corr_nomovers/pop)
		replace index = Cit5_corr_nomovers == 0
		replace innov = 0 if Cit5_corr_nomovers == 0	
			xi:xtivreg2 ltop1 (L2.innov =  L5.instru ) L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008, robust bw(2)  fe
			estimate store m2
			local m2 = e(widstat)	
			estadd scalar Fstat `m2'
			
		replace innov = log(Claims_nomovers/pop)
		replace index = Claims_nomovers == 0
		replace innov = 0 if Claims_nomovers == 0		
		xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011, robust bw(2) fe 
			estimate store m3
			local m3 = e(widstat)
			estadd scalar Fstat `m3'		
		
		replace innov = log(Generality_nomovers/pop)
		replace index = Generality_nomovers == 0
		replace innov = 0 if Generality_nomovers == 0		
		xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011, robust bw(2) fe 
		estimate store m4
		local m4 = e(widstat)	
		estadd scalar Fstat `m4'		
		
		replace innov = log(Top5_nomovers/pop)
		replace index = Top5_nomovers == 0
		replace innov = 0 if Top5_nomovers == 0
		xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008, robust bw(2) fe 
		estimate store m5	
		local m5 = e(widstat)
		estadd scalar Fstat `m5'		
		
		replace innov = log(Top1_nomovers/pop)
		replace index = Top1_nomovers == 0
		replace innov = 0 if Top1_nomovers == 0
		xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008, robust bw(2) fe 
		estimate store m6	
		local m6 = e(widstat)
		estadd scalar Fstat `m6'		
		
	}
	
	estout m1 m2 m3 m4 m5 m6 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL"  L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military") varwidth(40)
restore

//Table C21: Robustness 4: controlling for agglomeration effect - OLS and IV results
preserve
	qui {
		gen innov = log(Cit5_corr/pop)
		gen index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr==0	
		gen Agglo = (density_10pc1970)/1000
			xi:xtivreg2 ltop1 L2.innov  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage Agglo i.year if year <= 2008, robust bw(2) fe
			estimate store m1
		
		replace Agglo = (density_10pc2015)/1000
			xi:xtivreg2 ltop1 L2.innov  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage Agglo i.year if year <= 2008, robust bw(2) fe
			estimate store m2	
		
		replace Agglo =  (density_10pcMean)/1000
			xi:xtivreg2 ltop1 L2.innov  L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage Agglo i.year if year <= 2008, robust bw(2) fe
			estimate store m3	
		
		drop if iso == "DC"
		gen instru = Senate
		replace Agglo = (density_10pc1970)/1000
			xi:xtivreg2 ltop1 (L2.innov =  L5.instru ) L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  Agglo L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008, robust bw(2) fe 
			estimate store m4
			local m4 = e(widstat)		
			estadd scalar Fstat `m4'
		replace Agglo = (density_10pc2015)/1000
			xi:xtivreg2 ltop1 (L2.innov =  L5.instru ) L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  Agglo L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008, robust bw(2) fe 
			estimate store m5
			local m5 = e(widstat)
			estadd scalar Fstat `m5'		
		
		replace Agglo =  (density_10pcMean)/1000
			xi:xtivreg2 ltop1 (L2.innov =  L5.instru ) L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  Agglo L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008, robust bw(2) fe 
			estimate store m6
			local m6 = e(widstat)		
			estadd scalar Fstat `m6'
	}
	label var Agglo "Agglomeration"
	estout m1 m2 m3 m4 m5 m6 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL"  L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military") varwidth(40)
restore




//Table C14: Innovation and social mobility at the commuting zone level. Entrants and incumbents innovation
use ../data/CZ_main, clear

preserve	
	qui{
	gen innov = .
	gen LHS = log(am)
	label var laborforceparticipationrate "Participation Rate"
	label var schoolexpenditureperstudent "School Expenditure"
	label var manufacturingemploymentshare "Employment Manuf"
	
	gen innovE = log(Cit5_corr_entrant/pop)
	gen indexE = Cit5_corr_entrant == 0
	replace innovE = 0 if Cit5_corr_entrant == 0
	
	qui reg LHS innovE indexE lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
	estimate store m1, title("AM25")	
	
	replace LHS = log(pq5q1)
	qui reg LHS innovE indexE lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
	estimate store m2, title("P1-5")		

	replace LHS = log(pq5q2)
	qui reg LHS innovE indexE lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
	estimate store m3, title("P2-5")

	gen innovI = log(Cit5_corr_incumbent/pop)
	gen indexI = Cit5_corr_incumbent == 0
	replace innovI = 0 if Cit5_corr_incumbent == 0	
	
	replace LHS = log(am)	
	qui reg LHS innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
	estimate store m4	, title("AM25")
	
	replace LHS = log(pq5q1)
	qui reg LHS innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
	estimate store m5, title("P1-5")

	replace LHS = log(pq5q2)
	qui reg LHS innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
	estimate store m6, title("P2-5")
	
	replace LHS = log(am)	
	qui reg LHS innovE indexE innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop] , vce(cluster iso)
	estimate store m7	, title("AM25")
	}
	label var innovE "Innovation by entrants"
	label var innovI "Innovation by incumbents"
	estout m1 m2 m3 m4 m5 m6 m7 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* index* urbanareas) label  ///
	rename( lgdppc "Gdppc" lpop "Population" popgrowth "Popgrowth" gvt "Government" finance "Finance" localtaxrate "Tax" laborforceparticipationrate "Unemployment")  order(innovE innovI) varwidth(35) varlabel(innovE "Innovation by entrants" innovI "Innovation by incumbents")
restore


// Figure C1 has been computed from the file

use ../data/delta_lag, clear
	egen num = sum(share*delta)
	egen den = sum(share)
	gen mean = num/den
	su mean
	local m = r(mean)
	twoway bar share delta if delta < 8000, xline(`m') yline(0)  xtitle("Grant Lag (in days)") 
	graph export  "${graph}/graphC1.eps", replace as(eps)
