// Regression Replication file

use ../data/main_db, clear 
sort id year

	
// Reg 1: Top 1% income share and innovation
// Corresponds to Table 3 in the Paper
preserve
	qui {
		sort id year
		gen index = .	
		gen innov = log(patent/pop)
		replace index = patent == 0
		
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust bw(2) fe
			estimate store m1, title("Patents")
			
		replace innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe
			estimate store m2, title("Citations")
			
		replace innov = log(claims/pop)
		replace index = claims == 0
		replace innov = 0 if claims == 0	
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2011, robust bw(2) fe
			estimate store m3, title("Claims")
			
		replace innov = log(generality/pop)
		replace index = generality == 0
		replace innov = 0 if generality == 0		
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp  tax_gain tax_rate_wage   i.year if year <= 2011, robust bw(2) fe
			estimate store m4, title("Generality")
			
		replace innov = log(Top5/pop)
		replace index = Top5 == 0
		replace innov = 0 if Top5 == 0
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if year <= 2008, robust bw(2) fe
			estimate store m5, title("Top 5")
			
		replace innov = log(Top1/pop)
		replace index = Top1 == 0
		replace innov = 0 if Top1 == 0
			xi:xtivreg2 ltop1 L2.innov L2.index  lgdppc  popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe
			estimate store m6, title("Top 1")	
			
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* *index*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore


// Reg 2: Innovation and various measures of inequality
// Corresponds to Table 4 in the Paper
preserve
	qui {
		gen index = .
		gen innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage    i.year  if year <= 2008, robust bw(2) fe 
			estimate store m1, title("Top 1\%")

			xi:xtivreg2 ltop10 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage    i.year  if year <= 2008, robust bw(2) fe 
			estimate store m2, title("Top 10\%")
	
			xi:xtivreg2 ltop9 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m3, title("Avgtop")
		
			xi:xtivreg2 lgini L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage    i.year  if year <= 2008, robust bw(2) fe 
			estimate store m4, title("Gini")
		
			xi:xtivreg2 lgini99 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage    i.year  if year <= 2008, robust bw(2) fe 
			estimate store m5, title("Gini99")
		
			xi:xtivreg2 latkin L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m6, title("Atkin")		
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL")
restore

// Reg 3: Innovation and various measures of inequality vased on different income shares
// Corresponds to Table 5 in the Paper
preserve
	qui {
		sort id year

		
		gen index = .
		gen innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
				
			xi:xtivreg2 ltop10 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m1, title(top10)	
		
			xi:xtivreg2 ltop5 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m2, title(top5)		
					
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain   tax_rate_wage  i.year  if year <= 2008, robust bw(2) fe 
			estimate store m3, title(top1)				
					
			xi:xtivreg2 ltop05 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m4, title(top05)
			
			xi:xtivreg2 ltop01 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m5, title(top01)	
			
			xi:xtivreg2 ltop001 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   i.year  if year <= 2008, robust bw(2) fe 
			estimate store m6, title(top001)
		
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL")
restore

//Reg 4: Top 1% income share and innovation by entrants and incumbents
// Corresponds to Table 6 in the Paper
preserve
	qui {
		gen indexE = .
		gen indexI = .

		drop if year < 1976
		gen innovE = log(asg_entrant_patent_3y / pop)
		replace indexE = asg_entrant_patent_3y == 0
		replace innovE = 0 if asg_entrant_patent_3y == 0
			xi:xtivreg2 ltop1 L2.innovE L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2011 & year>= 1982, robust bw(2) fe
			estimate store m1, title("Patents")
		
		gen innovI = log(asg_incumbent_patent_3y /pop)
		replace indexI = asg_incumbent_patent_3y == 0
		replace innovI = 0 if asg_incumbent_patent_3y == 0
			xi:xtivreg2 ltop1 L2.innovI L2.indexI lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2011 & year>= 1982, robust bw(2) fe
			estimate store m2, title("Patents")	
				
			xi:xtivreg2 ltop1 L2.innovI L2.innovE L2.indexI L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2011 & year>= 1982, robust bw(2) fe
			estimate store m3, title("Patents")	
		
		replace innovE = log(asg_entrant_cit5_corr_3y /pop)
		replace indexE = asg_entrant_cit5_corr_3y == 0
		replace innovE = 0 if asg_entrant_cit5_corr_3y == 0
			xi:xtivreg2 ltop1 L2.innovE L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m4, title("Cit5")
		
		replace innovI = log(asg_incumbent_cit5_corr_3y /pop)
		replace indexI = asg_incumbent_cit5_corr_3y == 0
		replace innovI = 0 if asg_incumbent_cit5_corr_3y == 0
			xi:xtivreg2 ltop1 L2.innovI L2.indexI lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m5, title("Cit5")	
				
			xi:xtivreg2 ltop1 L2.innovI L2.innovE L2.indexI L2.indexE lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage i.year  if year <= 2008 & year>= 1982, robust bw(2) fe
			estimate store m6, title("Cit5")			
	}

	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations"))  drop(_* oL* *index*) label  order(L2.innovE L2.innovI) ///
	rename(lgdppc "Gdppc" finance "Finance" popgrowth "Popgrowth" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") varlabel(L2.innovE "Innovation by entrants" L2.innovI "Innovation by incumbents")	varwidth(30)
restore

// Reg 5: Top 1% income share, innovaiton and the role of lobbying intensity
// Corresponds to Table 7 in the Paper
preserve
	qui{
		gen index = .
		gen lobbying_pc = log((lobbying_bartik))


		gen innov = log(asg_entrant_patent_3y/pop)
		replace index = asg_entrant_patent_3y == 0
		replace innov = 0 if asg_entrant_patent_3y == 0
		gen interact = lobbying_pc * L2.innov
			xi:xtivreg2 ltop1 L2.innov L2.index interact lobbying_pc  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2011&year>=1982, robust bw(2) fe
			estimate store m1, title("Entrants")
				
		replace innov = log(asg_entrant_cit5_corr_3y/pop)
		replace index = asg_entrant_cit5_corr_3y == 0
		replace innov = 0 if asg_entrant_cit5_corr_3y == 0	
		replace interact = lobbying_pc * L2.innov
			xi:xtivreg2 ltop1 L2.innov L2.index interact  lobbying_pc  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2008&year>=1982, robust bw(2) fe
			estimate store m2, title("Entrants")
		
		replace innov = log(asg_entrant_claim_3y/pop)
		replace index = asg_entrant_claim_3y == 0
		replace innov = 0 if asg_entrant_claim_3y == 0	
		replace interact = lobbying_pc * L2.innov
			xi:xtivreg2 ltop1 L2.innov L2.index interact lobbying_pc  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2011&year>=1982, robust bw(2) fe
			estimate store m3, title("Entrants")
		
		replace innov = log(asg_incumbent_patent_3y/pop)
		replace index = asg_incumbent_patent_3y == 0
		replace innov = 0 if asg_incumbent_patent_3y == 0
		replace interact = lobbying_pc * L2.innov
			xi:xtivreg2 ltop1 L2.innov L2.index interact lobbying_pc  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2011&year>=1982, robust bw(2) fe
			estimate store m4, title("Incumbents")		
		
		replace innov = log(asg_incumbent_cit5_corr_3y/pop)
		replace index = asg_incumbent_cit5_corr_3y == 0
		replace innov = 0 if asg_incumbent_cit5_corr_3y == 0	
		replace interact = lobbying_pc * L2.innov
			xi:xtivreg2 ltop1 L2.innov L2.index interact lobbying_pc  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2008&year>=1982, robust bw(2) fe
			estimate store m5, title("Incumbents")
				
		replace innov = log(asg_incumbent_claim_3y/pop)
		replace index = asg_incumbent_claim_3y == 0
		replace innov = 0 if asg_incumbent_claim_3y == 0	
		replace interact = lobbying_pc * L2.innov
			xi:xtivreg2 ltop1 L2.innov L2.index interact lobbying_pc  lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage  i.year  if year <= 2011&year>=1982, robust bw(2) fe
			estimate store m6, title("Incumbents")
		
	}

	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) p(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* oL*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popogrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL") 
restore


// Reg6: Top1% income share and innovaiton at different lags
// Corresponds to Table 8 in the Paper
preserve
	qui {
		gen index = .
		gen innov = log(Cit5/pop)
		replace index = Cit5 == 0
		replace innov = 0 if Cit5 == 0			
			xi:xtivreg2 ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if L6.innov != . & year <= 2008, robust bw(2) fe
			estimate store m1, title("2 years")
		
			xi:xtivreg2 ltop1 L3.innov L3.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if L6.innov != . & year <= 2008, robust bw(2) fe
			estimate store m2, title("3 years")
		
			xi:xtivreg2 ltop1 L4.innov L4.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if L6.innov != . & year <= 2008, robust bw(2) fe
			estimate store m3, title("4 years")

			xi:xtivreg2 ltop1 L5.innov L5.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if L6.innov != . & year <= 2008, robust bw(2) fe
			estimate store m4, title("5 years")

			xi:xtivreg2 ltop1 L6.innov L6.index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year  if L6.innov != . & year <= 2008, robust bw(2) fe
			estimate store m5, title("6 years")		
	
			xi:xtivreg2 ltop1 L(2/6).innov L(2/6).index lgdppc popgrowth finance gvt unemp tax_gain tax_rate_wage   i.year if L6.innov != . & year <= 2008, robust bw(2) fe partial(i.year)
			estimate store m6, title("6 years")		
	}
	estout m1 m2 m3 m4 m5 m6, cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) label ///
	rename(L2.innov "Innovation_{t-2}" L3.innov "Innovation_{t-3}" L4.innov "Innovation_{t-4}" L5.innov "Innovation_{t-5}" L6.innov "Innovation_{t-6}" lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL" ) ///
	order("Innovation_{t-2}"  "Innovation_{t-3}" "Innovation_{t-4}" "Innovation_{t-5}" "Innovation_{t-6}") varwidth(35) drop(_* oL* *index*)
restore

// Reg7: Seanate Appropriation Commitee Composition and earmarks
// Data on earmarks have been directly provided by Cohen et al (2011)
/* Do Powerful Politicians Cause Corporate Downsizing?
   Lauren Cohen, Joshua Coval, and Christopher Malloy
   Journal of Political Economy 2011 119:6, 1015-1060 */
// This corresponds to Table 9 in the paper   

// Reg8: Regression on Top 1% Income shar eusing instrument based on appropriation committee composition in the senate  
// Corresponds to Table 10 in the Paper
preserve
	qui {		
		gen instru = Senate

		gen index = .
		gen innov = log(patent/pop)
		drop if iso == "DC"
		replace index = patent == 0
		replace innov = 0 if patent == 0	
			xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011, robust  fe bw(2)
			estimate store m1
			local m1 = e(widstat)
			estadd scalar Fstat = `m1'		
		
		replace innov = log(Cit5_corr/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008 , robust fe bw(2) 
			estimate store m2
			local m2 = e(widstat)	
			estadd scalar Fstat = `m2'		
		
		replace innov = log(claims/pop)
		replace index = claims == 0
		replace innov = 0 if claims == 0		
			xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011, robust  fe bw(2) 
			estimate store m3
			local m3 = e(widstat)	
			estadd scalar Fstat = `m3'		

		replace innov = log(generality/pop)
		replace index = generality == 0
		replace innov = 0 if generality == 0		
			xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2011, robust fe bw(2) 
			estimate store m4
			local m4 = e(widstat)		
			estadd scalar Fstat = `m4'		

		replace innov = log(Top5/pop)
		replace index = Top5 == 0
		replace innov = 0 if Top5 == 0
			xi:xtivreg2 ltop1 (L2.innov = L5.instru) L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp i.year if year <= 2008 , robust fe bw(2) 
			estimate store m5	
			local m5 = e(widstat)		
			estadd scalar Fstat = `m5'		
	
		replace innov = log(Top1/pop)
		replace index = Top1 == 0
		replace innov = 0 if Top1 == 0
			xi:xtivreg2 ltop1 (L2.innov = L5.instru ) L2.index lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage   L5.share_fed_rev_highways L5.fed_def_gdp  i.year if year <= 2008 , robust  fe bw(2) 
			estimate store m6	
			local m6 = e(widstat)		
			estadd scalar Fstat = `m6'		
	}
	
	estout m1 m2 m3 m4 m5 m6 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2  Fstat N, fmt(%9.3f %9.1f %9.0g ) label("R\textsuperscript{2}" "F-stat on the excluded instruments" "Observations")) drop(_* *index*) label  ///
	rename(L2.innov "Innovation" lgdppc "Gdppc" popgrowth "Popgrowth"  finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK" tax_rate_wage "TaxL" L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military") 
restore   

// Reg9 First stage and reduced form equation estimations
// Corresponds to Table 11 in the Paper
preserve
	qui {
		sort id year
		gen index = .
		drop if iso == "DC"
		replace Cit5_corr = . if year < 1976
		gen control = log(control_spillover)
		gen control2 = log(control_spill_indus)
		gen instru = Senate 
		gen instru2 = log(instru_spill) 
		gen innov = log((Cit5_corr)/pop)
		replace index = Cit5_corr == 0
		replace innov = 0 if Cit5_corr == 0	
			xi:xtivreg2 L2.innov L5.instru  L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L5.share_fed_rev_highways L5.fed_def_gdp i.year  if year <= 2008, fe robust bw(2) 
			estimate store m1
			xi:ivreg2 ltop1  L5.instru L2.index  lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L5.share_fed_rev_highways L5.fed_def_gdp  i.year i.id if L2.innov != . & year <= 2008, robust bw(2) 
			estimate store m2
		
			xi:xtivreg2 L2.innov  L3.instru2 L2.index   lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L3.control L3.control2 i.year  if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m3
			xi:xtivreg2 ltop1 L3.instru2 L2.index    lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L3.control L3.control2  i.year  if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m4
			
			xi:xtivreg2 L2.innov  L5.instru L3.instru2 L2.index    lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage L5.share_fed_rev_highways L5.fed_def_gdp L3.control L3.control2  i.year  if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m5
			xi:xtivreg2 ltop1  L5.instru L3.instru2 L2.index    lgdppc popgrowth finance gvt unemp tax_gain  tax_rate_wage  L5.share_fed_rev_highways L5.fed_def_gdp L3.control L3.control2  i.year  if year <= 2008 & year >=1982, robust bw(2) fe 
			estimate store m6
		
	}		
		
	estout m1 m2 m3 m4 m5 m6 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* *index* *control*) label  ///
	rename(lgdppc "Gdppc" popgrowth "Popgrowth" finance "Finance" gvt "Government" unemp "Unemployment" tax_gain "TaxK"  tax_rate_wage "TaxL" L5.share_fed_rev_highways "Highways" L5.fed_def_gdp "Military")  ///
	order(L5.instru L3.instru2) varlabel(L5.instru "Appropriation Committee" L3.instru2 "Spillover")  varwidth(30)
restore	



//Reg10: Top 1% Income Share and innovation, CZ level panel 
// Corresponds to Table 13 in the Paper
use ../data/cz_panel, clear
set matsize 1000
preserve	
	gen innov = .
	gen index = .
	sort cz year
	replace innov = log(patent/pop)
	replace innov = 0 if patent == 0
	replace index = patent == 0
	gen group = . if ltop1 == .

	qui areg ltop1 L2.innov L2.index year#statefip  [aw=pop] if inrange(year, 1998, 2011)  , a(cz) robust cluster(statefip) 
	estimate store m1
	qui areg ltop1 L2.innov L2.index lgdppc year#statefip [aw=pop] if inrange(year, 1998, 2011)  , a(cz) cluster(statefip)  
	estimate store m2
	qui areg ltop1 L2.innov L2.index lgdppc popgrowth  year#statefip  [aw=pop] if inrange(year, 1998, 2011)  , a(cz) cluster(statefip)   
	estimate store m3
	qui areg ltop1 L2.innov L2.index lgdppc popgrowth finance gvt  year#statefip  [aw=pop] if inrange(year, 1998, 2011)  , a(cz) cluster(statefip)   
	estimate store m4
	qui areg ltop1 L2.innov L2.index lgdppc popgrowth finance gvt unemp  year#statefip [aw=pop] if inrange(year, 1998, 2011)  , a(cz) cluster(statefip)  
	estimate store m5

	
	estout m1 m2 m3 m4 m5 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* *year* *index*) label delimiter(&) end(\\) ///
	rename(L2.innov "Innovation" lgdppc "Gdppc"  popgrowth "Popgrowth" gvt "Government" finance "Finance" unemp "Unemployment")
restore




use ../data/CZ_main, clear

//Reg11: Innovation and social mobility at the commuting zone level
// Corresponds to Table 14 in the Paper
preserve	
	qui{
		gen innov = log(Cit5_corr/pop) 
		replace innov = 0 if Cit5_corr == 0
		gen index = Cit5_corr == 0
		
		
		gen LHS = log(am)
		qui reg LHS innov index lgdppc   popgrowth gvt finance laborforceparticipationrate localtaxrate  urbanarea  [aw=pop],  vce(cluster iso) 
		estimate store m1		
		
		replace LHS = log(pq5q1)
		qui reg LHS innov index lgdppc   popgrowth finance gvt laborforceparticipationrate localtaxrate urbanarea  [aw=pop] ,  vce(cluster iso)
		estimate store m2		

		replace LHS = log(pq5q2)
		qui reg LHS innov index lgdppc  popgrowth finance gvt laborforceparticipationrate  localtaxrate  urbanarea   [aw=pop] , vce(cluster iso)
		estimate store m3

		replace LHS = log(am)	
		qui reg LHS innov index lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop],  vce(cluster iso)
		estimate store m4	
		
		replace LHS = log(pq5q1)
		qui reg LHS innov index lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop] , vce(cluster iso)
		estimate store m5

		replace LHS = log(pq5q2)
		qui reg LHS innov index lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop] , vce(cluster iso)
		estimate store m6
		
		replace LHS = log(pq5)	
		qui reg LHS innov index lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare  urbanarea  [aw=pop] , vce(cluster iso)
		estimate store m7	
	}
		estout m1 m2 m3 m4 m5 m6 m7 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* index urbanareas) label  ///
		rename(innov "Innovation" lgdppc "Gdppc" lpop "Population" popgrowth "Popgrowth" gvt "Government" finance "Finance" localtaxrate "Tax" laborforceparticipationrate "Unemployment") 
restore


//reg12: Innovation and social mobility at the CZ level. Entrant and incumbents innovation and lobbying
// Corresponds to Table 15 in the Paper
preserve	
	qui{
		drop if lobbying == .
		replace lobbying = lobbying / income
		sort urbanarea lobbying
		by urbanarea: gen above_median = _n > _N/2
		gen innov = .
		gen LHS = log(am)
				
		gen innovE = log(Cit5_corr_entrant/pop)
		gen indexE = Cit5_corr_entrant == 0
		replace innovE = 0 if Cit5_corr_entrant == 0
		
		qui reg LHS innovE indexE lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
		estimate store m1		
		
		gen innovI = log(Cit5_corr_incumbent/pop)
		gen indexI = Cit5_corr_incumbent == 0
		replace innovI = 0 if Cit5_corr_incumbent == 0	
		
		replace LHS = log(am)	
		qui reg LHS innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea  [aw=pop]  , vce(cluster iso)
		estimate store m2
		
		replace LHS = log(am)
		
		qui reg LHS innovE indexE innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent    manufacturingemploymentshare urbanarea  [aw=pop] , vce(cluster iso)
		estimate store m3
		
		qui reg LHS innovE indexE innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea [aw=pop] if above_median == 1 , vce(cluster iso)
		estimate store m4	
		
		qui reg LHS innovE indexE innovI indexI lgdppc  popgrowth finance gvt  laborforceparticipationrate localtaxrate schoolexpenditureperstudent   manufacturingemploymentshare urbanarea [aw=pop]  if above_median == 0 , vce(cluster iso)
		estimate store m5		
	
	}
	label var innovE "Innovation by entrants"
	label var innovI "Innovation by incumbents"
	estout m1 m2 m3 m4 m5 , cells(b(fmt(3) star) se(fmt(3) par)) starlevels(* 0.10 ** 0.05 *** .01) stats(r2 N, fmt(%9.3f %9.0g) label("R\textsuperscript{2}" "Observations")) drop(_* index* urbanareas) label ///
	rename( lgdppc "Gdppc" lpop "Population" popgrowth "Popgrowth" gvt "Government" finance "Finance" localtaxrate "Tax")  order(innovE innovI) varlabel(innovE "Innovation by entrants" innovI "Innovation by incumbents") varwidth(30)
restore




	
	
